@@ -39,6 +39,7 @@ static shell::stringopt iface('A', "--address", _TEXT("sip interface address"),
 static shell::numericopt port('P', "--port", _TEXT("sip port to bind"), "port", 5060);
 static shell::flagopt backflag('b', "--background", _TEXT("run in background"));
 static shell::flagopt altback('d', NULL, NULL);
+static shell::flagopt dump('D', "--dump-config", _TEXT("show configuration"));
 static shell::numericopt concurrency('c', "--concurrency", _TEXT("process concurrency"), "level");
 static shell::flagopt desktop(0, "--desktop", _TEXT("enable desktop access"));
 static shell::flagopt foreflag('f', "--foreground", _TEXT("run in foreground"));
@@ -48,6 +49,7 @@ static shell::stringopt group('g', "--group", _TEXT("use specified group permiss
 static shell::numericopt histbuf('h', "--history", _TEXT("set history buffer"), "count", 0);
 static shell::stringopt loglevel('L', "--logging", _TEXT("set log level"), "level", "err");
 static shell::stringopt loading('l', "--plugins", _TEXT("specify modules to load"), "names", "none");
+static shell::flagopt nolocalusers('n', "--no-localusers", _TEXT("disable local user accounts"));
 static shell::counteropt priority('p', "--priority", _TEXT("set priority level"), "level");
 static shell::flagopt restart('r', "--restartable", _TEXT("set to restartable process"));
 static shell::flagopt trace('t', "--trace", _TEXT("trace sip messages"));
@@ -58,6 +60,11 @@ static shell::flagopt verbose('v', NULL, _TEXT("set verbosity, can be used multi
 static shell::flagopt version(0, "--version", _TEXT("show version information"));
 static shell::numericopt debuglevel('x', "--debug", _TEXT("set debug level directly"), "level", 0);
 
+static shell::groupopt groupconfig(_TEXT("User Options"));
+static shell::stringopt configpath(0, "--configpath", _TEXT("config file"), "path", NULL);
+static shell::stringopt cachepath(0, "--cachepath", _TEXT("cache files"), "dir", NULL);
+static shell::stringopt prefixpath(0, "--prefixpath", _TEXT("provisioning files"), "dir", NULL);
+
 #if defined(HAVE_SETRLIMIT) && defined(DEBUG)
 #include <sys/time.h>
 #include <sys/resource.h>
@@ -85,6 +92,21 @@ static void corefiles(void)
 }
 #endif
 
+static const char *userpath(const char *path)
+{
+    if(!path)
+        return NULL;
+
+#ifndef _MSWINDOWS_
+    if(eq(path, "~/", 2) && getuid()) {
+        const char *home = getenv("HOME");
+        if(home)
+            return strdup(str(home) + ++path);
+    }
+#endif
+    return path;
+}
+
 static void usage(void)
 {
 #if defined(DEBUG)
@@ -119,6 +141,20 @@ static void versioninfo(void)
     exit(0);
 }
 
+static void dumpconfig(void)
+{
+    const char *dirpath = control::env("users");    // /etc/sipwitch.d
+    if(!dirpath)
+        dirpath = control::env("prefix");
+
+    printf("config:    %s\n", control::env("config"));
+    printf("control:   %s\n", control::env("control"));
+    printf("runtime:   %s\n", control::env("controls"));
+    printf("cache:     %s\n", control::env("cache"));
+    printf("provision: %s\n", dirpath);
+    exit(0);
+}
+
 static bool errlog(shell::loglevel_t level, const char *text)
 {
     switch(level) {
@@ -198,6 +234,14 @@ static void init(int argc, char **argv, bool detached, shell::mainproc_t svc = N
     }
 #endif
 
+    // parse and check for help
+    args.parse(argc, argv);
+    if(is(helpflag) || is(althelp) || args.argc() > 0)
+        usage();
+
+    if(is(version))
+        versioninfo();
+
     // cheat out shell parser...
     // argv[0] = (char *)"sipwitch";
 
@@ -230,6 +274,7 @@ static void init(int argc, char **argv, bool detached, shell::mainproc_t svc = N
     prefix = DEFAULT_VARPATH "/lib/sipwitch";
     rundir = DEFAULT_VARPATH "/run/sipwitch";
     args.setsym("reply", "/tmp/.sipwitch.");
+
     args.setsym("config", DEFAULT_CFGPATH "/sipwitch.conf");
     args.setsym("cache", DEFAULT_VARPATH "/cache/sipwitch");
     args.setsym("controls", DEFAULT_VARPATH "/run/sipwitch");
@@ -241,7 +286,7 @@ static void init(int argc, char **argv, bool detached, shell::mainproc_t svc = N
     args.setsym("logfile", DEFAULT_VARPATH "/log/sipwitch.log");
     args.setsym("calls", DEFAULT_VARPATH "/log/sipwitch.calls");
     args.setsym("stats", DEFAULT_VARPATH "/log/sipwitch.stats");
-    args.setsym("prefix", DEFAULT_VARPATH "/lib/sipwitch");
+    args.setsym("prefix", prefix);
     args.setsym("shell", "/bin/sh");
 #endif
 
@@ -265,17 +310,34 @@ static void init(int argc, char **argv, bool detached, shell::mainproc_t svc = N
         args.setsym("callmap", _STR(str(CALL_MAP "-") + str(pwd->pw_name)));
         args.setsym("regmap", _STR(str(REGISTRY_MAP "-") + str(pwd->pw_name)));
 
-        args.setsym("config", _STR(str(pwd->pw_dir) + "/.sipwitchrc"));
+        cp = userpath(*configpath);
+        if(is(configpath) && fsys::isfile(cp))
+            args.setsym("config", cp);
+        else
+            args.setsym("config", _STR(str(pwd->pw_dir) + "/.sipwitchrc"));
+
+        cp = userpath(*cachepath);
+        if(is(cachepath) && fsys::isdir(cp))
+            args.setsym("cache", cp);
+        else
+            args.setsym("cache", _STR(str(rundir) + "/cache"));
+
         args.setsym("controls", rundir);
         args.setsym("control", _STR(str(rundir) + "/control"));
-        args.setsym("cache", _STR(str(rundir) + "/cache"));
         args.setsym("events", _STR(str(rundir) + "/events"));
         args.setsym("logfiles", rundir);
         args.setsym("siplogs", _STR(str(rundir) + "/siplogs"));
         args.setsym("logfile", _STR(str(rundir) + "/logfile"));
         args.setsym("calls", _STR(str(rundir) + "/calls"));
         args.setsym("stats", _STR(str(rundir) + "/stats"));
-        args.setsym("prefix", prefix);
+
+
+        cp = userpath(*prefixpath);
+        if(is(prefixpath) && fsys::isdir(cp))
+            args.setsym("prefix", cp);
+        else
+            args.setsym("prefix", prefix);
+
         args.setsym("shell", pwd->pw_shell);
     }
 
@@ -312,6 +374,11 @@ static void init(int argc, char **argv, bool detached, shell::mainproc_t svc = N
             server::sipadmin = strdup(cp);
     }
 
+    if(is(nolocalusers)) {
+        server::sipusers = NULL;
+        server::sipadmin = NULL;
+    }
+
 #endif
 
     cp = args.getenv("CONCURRENCY");
@@ -338,13 +405,10 @@ static void init(int argc, char **argv, bool detached, shell::mainproc_t svc = N
     if(cp && *cp)
         loading.set(strdup(cp));
 
-    // parse and check for help
-    args.parse(argc, argv);
-    if(is(helpflag) || is(althelp) || args.argc() > 0)
-        usage();
-
-    if(is(version))
-        versioninfo();
+    if(is(dump)) {
+        control::config(&args);
+        dumpconfig();
+    }
 
     // check validity of some options...
 
